/*
 * Gridbox.h - Public definitions for Gridbox widget
 */

#ifndef GRIDBOX_H
#define GRIDBOX_H

/* Resources:

 Name               Class               RepType     Default Value
 ----               -----               -------     -------------
 background         Background          Pixel       XtDefaultBackground
 border             BorderColor         Pixel       XtDefaultForeground
 borderWidth        BorderWidth         Dimension   1
 defaultDistance    Thickness           int         4
 destroyCallback    Callback            Pointer     NULL
 width              Width               Dimension   computed at realize
 height             Height              Dimension   computed at realize
 mappedWhenManaged  MappedWhenManaged   Boolean     True
 x                  Position            Position    0
 y                  Position            Position    0


  "defaultDistance" specifies the default margin around child widgets, all
  other resources are the same as for Constraint.

*/

/* Constraint resources:

 Name            Class      RepType     Default Value
 ----            -----      -------     -------------
 gridx          Position    Position    0
 gridy          Position    Position    0
 gridWidth      Width       Dimension   1
 gridHeight     Height      Dimension   1
 fill           Fill        FillType    FillBoth
 gravity        Gravity     Gravity     CenterGravity
 weightx        Weight      int         0
 weighty        Weight      int         0
 margin         Margin      int         defaultDistance


  gridx, gridy          position of child in grid.  Upper-left cell is 0,0
  gridWidth, gridHeight size of child in cells.
  fill                  "none", "width", "height" or "both"
  gravity               position of child within cell when cell is larger.
                        See <X11/X.h> for list.
  weightx, weighty      effects how excess space is allocated to cells
  margin                margin around child within cell

*/

#ifndef XtNdefaultDistance
#define XtNdefaultDistance "defaultDistance"
#endif

#ifndef XtNgridx
#define XtNgridx "gridx"
#endif
#ifndef XtNgridy
#define XtNgridy "gridy"
#endif
#ifndef XtNgridWidth
#define XtNgridWidth "gridWidth"
#endif
#ifndef XtNgridHeight
#define XtNgridHeight "gridHeight"
#endif
#ifndef XtNfill
#define XtNfill "fill"
#endif
#ifndef XtCFill
#define XtCFill "Fill"
#endif
#ifndef XtRFillType
#define XtRFillType "FillType"
#endif
#ifndef XtNgravity
#define XtNgravity "gravity"
#endif
#ifndef XtCgravity
#define XtCGravity "Gravity"
#endif
#ifndef XtNweightx
#define XtNweightx "weightx"
#endif
#ifndef XtNweighty
#define XtNweighty "weighty"
#endif
#ifndef XtNmargin
#define XtNmargin "margin"
#endif
#ifndef XtCWeight
#define XtCWeight "Weight"
#endif

typedef unsigned int FillType;
#define FillNone   0
#define FillWidth  1
#define FillHeight 2
#define FillBoth   (FillWidth|FillHeight)

typedef struct GridboxClassRec *GridboxWidgetClass;
typedef struct GridboxRec *GridboxWidget;

extern WidgetClass gridboxWidgetClass;

_XFUNCPROTOBEGIN

_XFUNCPROTOEND
 
#endif /* GRIDBOX_H */
