/*
 * SliderP.h - Private definitions for Slider widget
 */

#ifndef SLIDERP_H
#define SLIDERP_H

typedef void (*sliderProc)(SliderWidget);
typedef void (*sliderBgProc)(SliderWidget, int x, int y, int wid, int hgt);
typedef void (*sliderMoveProc)(SliderWidget, int newpos);
typedef void (*sliderPrefSize)(SliderWidget, Dimension *, Dimension *,
	Dimension *, Dimension *);

/* programming note: The convention is to define these as _XtInherit, but
 * since NULL is not permitted in the class structure, things work out
 * better if I do it this way.
 */

#define XtInheritDrawBorder NULL
#define XtInheritDrawBackground NULL
#define XtInheritDrawThumb NULL
#define XtInheritMoveThumb NULL
#define XtInheritFocusProc NULL
#define XtInheritPreferredSize NULL

typedef struct SliderClassPart {
	sliderProc draw_border;
	sliderBgProc draw_background;
	sliderProc draw_thumb;
	sliderMoveProc move_thumb;
	sliderProc focus_proc;
	sliderPrefSize preferred_size;
	XtPointer extension;
} SliderClassPart;

/* Full class record declaration */
typedef struct SliderClassRec {
	CoreClassPart core_class;
	SliderClassPart slider_class;
} SliderClassRec;

extern SliderClassRec sliderClassRec;

/****************************************************************
 *
 * instance record declaration
 *
 ****************************************************************/

/* New fields for the Slider widget record */
typedef struct SliderPart {
	/* resources */
	XFontStruct *font;
	Pixel foreground;
	int minimum, maximum, value;
	int step, step2;
	XtOrientation orientation;
	short decimalPoints;
	short inputScale;
	short thumbLength;
	Boolean showValue;
	Boolean autoScale;
	XtCallbackList dragCallback;
	XtCallbackList valueChangedCallback;
	short shadowWidth;
	short top_contrast;
	short bot_contrast;
	short arm_contrast;
	short insensitive_contrast;
	Boolean be_nice_to_cmap;

	/* private state */
	Boolean needs_layout;
	Boolean has_focus;
	GC foregroundGC;
	GC backgroundGC;
	GC greyGC;
	GC topGC;
	GC botGC;
	Pixmap grey50; /* TODO: cache this elsewhere */
	int oldvalue;
	short start; /* first pixel thumb may occupy */
	short length; /* working length */
	short thumbpos;
	short adjustPt;
	short thumbWidth;
	Boolean adjusting;
	XtPointer extension;
} SliderPart;


typedef struct SliderRec {
	CorePart core;
	SliderPart slider;
} SliderRec;



	/* internals */

#define SliderClass(w) ((SliderWidgetClass)(w)->core.widget_class)


_XFUNCPROTOBEGIN

extern void
_SliderThumb(SliderWidget , int *, int *, int *, int *);

_XFUNCPROTOEND

#endif /* SLIDERP_H */
