/*
 * Copyright (c) 2003 Chris Wareham.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. The name of the author may not be used to endorse or promote products
 *    derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN
 * ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

#include <stdlib.h>

#include <X11/Intrinsic.h>
#include <X11/StringDefs.h>
#include <X11/Shell.h>
#include <X11/Xaw/Box.h>
#include <X11/Xaw/Command.h>
#include <X11/Xaw/Dialog.h>
#include <X11/Xaw/Form.h>
#include <X11/Xaw/Label.h>
#include <X11/Xaw/Toggle.h>

#include "preferences.h"

PrefsDialog *
create_prefs_dialog(Widget parent)
{
	PrefsDialog *pd;
	Widget textbox, togglebox, buttonbox;

	pd = malloc(sizeof(PrefsDialog));

	pd->dialog = XtVaCreatePopupShell("prefs_dialog", transientShellWidgetClass, parent,
		NULL);

	pd->form = XtVaCreateManagedWidget("prefs_form", formWidgetClass, pd->dialog,
		NULL);

	pd->label = XtVaCreateManagedWidget("prefs_label", labelWidgetClass, pd->form,
		XtNtop,   XtChainTop,
		XtNleft,  XtChainLeft,
		XtNright, XtChainRight,
		NULL);

	textbox = XtVaCreateManagedWidget("prefs_textbox", formWidgetClass, pd->form,
		XtNfromVert, pd->label,
		XtNleft,     XtChainLeft,
		NULL);

	pd->time = XtVaCreateManagedWidget("prefs_time", dialogWidgetClass, textbox,
		XtNtop,   XtChainTop,
		XtNleft,  XtChainLeft,
		XtNright, XtChainRight,
		NULL);

	pd->date = XtVaCreateManagedWidget("prefs_date", dialogWidgetClass, textbox,
		XtNfromVert, pd->time,
		XtNleft,     XtChainLeft,
		XtNright,    XtChainRight,
		NULL);

	pd->message = XtVaCreateManagedWidget("prefs_message", dialogWidgetClass, textbox,
		XtNfromVert, pd->date,
		XtNleft,     XtChainLeft,
		XtNright,    XtChainRight,
		NULL);

	pd->program = XtVaCreateManagedWidget("prefs_program", dialogWidgetClass, textbox,
		XtNfromVert, pd->message,
		XtNleft,     XtChainLeft,
		XtNright,    XtChainRight,
		NULL);

	togglebox = XtVaCreateManagedWidget("prefs_togglebox", boxWidgetClass, pd->form,
		XtNfromVert,    pd->label,
		XtNfromHoriz,   textbox,
		XtNright,       XtChainRight,
		XtNorientation, XtorientVertical,
		NULL);

	pd->mon = XtVaCreateManagedWidget("prefs_mon", toggleWidgetClass, togglebox,
		NULL);
	pd->tue = XtVaCreateManagedWidget("prefs_tue", toggleWidgetClass, togglebox,
		NULL);
	pd->wed = XtVaCreateManagedWidget("prefs_wed", toggleWidgetClass, togglebox,
		NULL);
	pd->thu = XtVaCreateManagedWidget("prefs_thu", toggleWidgetClass, togglebox,
		NULL);
	pd->fri = XtVaCreateManagedWidget("prefs_fri", toggleWidgetClass, togglebox,
		NULL);
	pd->sat = XtVaCreateManagedWidget("prefs_sat", toggleWidgetClass, togglebox,
		NULL);
	pd->sun = XtVaCreateManagedWidget("prefs_sun", toggleWidgetClass, togglebox,
		NULL);

	buttonbox = XtVaCreateManagedWidget("prefs_buttonbox", boxWidgetClass, pd->form,
		XtNfromVert,    textbox,
		XtNleft,        XtChainLeft,
		XtNright,       XtChainRight,
		XtNbottom,      XtChainBottom,
		XtNorientation, XtEhorizontal,
		NULL);

	pd->ok = XtVaCreateManagedWidget("prefs_ok", commandWidgetClass, buttonbox,
		NULL);
	pd->cancel = XtVaCreateManagedWidget("prefs_cancel", commandWidgetClass, buttonbox,
		NULL);

	return pd;
}
